@@ -5,17 +5,13 @@
 #include <ctype.h>
 #include "owl.h"
 
-static const char fileIdent[] = "$Id$";
-
-static int in_regtest = 0;
-
 #define OWLVAR_BOOL(name,default,summary,description) \
         { name, OWL_VARIABLE_BOOL, NULL, default, "on,off", summary,description, NULL, \
-        NULL, NULL, NULL, NULL, NULL }
+        NULL, NULL, NULL, NULL, NULL, NULL }
 
 #define OWLVAR_BOOL_FULL(name,default,summary,description,validate,set,get) \
         { name, OWL_VARIABLE_BOOL, NULL, default, "on,off", summary,description, NULL, \
-        validate, set, NULL, get, NULL }
+        validate, set, NULL, get, NULL, NULL }
 
 #define OWLVAR_INT(name,default,summary,description) \
         { name, OWL_VARIABLE_INT, NULL, default, "<int>", summary,description, NULL, \
@@ -189,7 +185,8 @@ static owl_variable variables_to_init[] = {
 
   OWLVAR_PATH( "debug_file" /* %OwlVarStub */, OWL_DEBUG_FILE,
 	       "path for logging debug messages when debugging is enabled",
-	       "This file will be logged to if 'debug' is set to 'on'.\n"),
+	       "This file will be logged to if 'debug' is set to 'on'.\n"
+               "BarnOwl will append a dot and the current process's pid to the filename."),
   
   OWLVAR_PATH( "zsigproc" /* %OwlVarStub:zsigproc */, NULL,
 	       "name of a program to run that will generate zsigs",
@@ -212,6 +209,12 @@ static owl_variable variables_to_init[] = {
          "principal. Note that customizing the sender name will\n"
          "cause your zephyrs to be sent unauthenticated."),
 
+  OWLVAR_STRING( "zsigfunc" /* %OwlVarStub */, "BarnOwl::default_zephyr_signature()",
+		 "zsig perl function",
+		 "Called every time you start a zephyrgram without an\n"
+		 "explicit zsig.  The default setting implements the policy\n"
+		 "descripted in the documentation for the 'zsig' variable.\n"),
+
   OWLVAR_STRING( "zsig" /* %OwlVarStub */, "",
 	         "zephyr signature",
 		 "The zsig to get on outgoing messages. If this variable is\n"
@@ -285,7 +288,7 @@ static owl_variable variables_to_init[] = {
 		 "if it is narrower than the maximum, or if this\n"
 		 "is set to 0.\n" ),
 
-  OWLVAR_INT(    "edit:maxwrapcols" /* %OwlVarStub:edit_maxwrapcols */, 0,
+  OWLVAR_INT(    "edit:maxwrapcols" /* %OwlVarStub:edit_maxwrapcols */, 70,
 	         "maximum number of columns for line-wrapping",
 		 "This specifies the maximum number of columns for\n"
 		 "auto-line-wrapping.  If set to 0, ther will be no maximum\n"
@@ -294,7 +297,7 @@ static owl_variable variables_to_init[] = {
 		 "if it is narrower than the maximum, or if this\n"
 		 "is set to 0.\n\n"
 		 "It is recommended that outgoing messages be no wider\n"
-		 "than 60 columns, as a courtesy to recipients.\n"),
+		 "than 70 columns, as a courtesy to recipients.\n"),
 
   OWLVAR_INT( "aim_ignorelogin_timer" /* %OwlVarStub */, 15,
 	      "number of seconds after AIM login to ignore login messages",
@@ -355,6 +358,13 @@ static owl_variable variables_to_init[] = {
 	       "                 the cursor will be near the center.\n",
 	       "normal,top,neartop,center,paged,pagedcenter" ),
 
+  OWLVAR_BOOL( "narrow-related" /* %OwlVarStub:narrow_related */, 1,
+               "Make smartnarrow use broader filters",
+               "Causes smartfiler to narrow to messages \"related\" to \n"
+               "the current message, as well as ones to the same place.\n\n"
+               "for Zephyr, this controls whether to narrow to e.g. class-help or\n"
+               "class-help.d alone, or to related-class-help, which includes\n"
+               "help, unhelp, help.d, etc.\n\nDefault is true (include unclasses, etc.).\n" ),
 
   OWLVAR_BOOL( "_followlast" /* %OwlVarStub */, 0,
 	       "enable automatic following of the last zephyr",
@@ -376,22 +386,22 @@ static owl_variable variables_to_init[] = {
 
 /* commonly useful */
 
-int owl_variable_int_validate_gt0(owl_variable *v, void *newval)
+int owl_variable_int_validate_gt0(const owl_variable *v, const void *newval)
 {
   if (newval == NULL) return(0);
-  else if (*(int*)newval < 1) return(0);
+  else if (*(const int*)newval < 1) return(0);
   else return (1);
 }
 
-int owl_variable_int_validate_positive(owl_variable *v, void *newval)
+int owl_variable_int_validate_positive(const owl_variable *v, const void *newval)
 {
   if (newval == NULL) return(0);
-  else if (*(int*)newval < 0) return(0);
+  else if (*(const int*)newval < 0) return(0);
   else return (1);
 }
 
 /* typewinsize */
-int owl_variable_typewinsize_set(owl_variable *v, void *newval)
+int owl_variable_typewinsize_set(owl_variable *v, const void *newval)
 {
   int rv;
   rv = owl_variable_int_set_default(v, newval);
@@ -400,31 +410,31 @@ int owl_variable_typewinsize_set(owl_variable *v, void *newval)
 }
 
 /* debug (cache value in g->debug) */
-int owl_variable_debug_set(owl_variable *v, void *newval)
+int owl_variable_debug_set(owl_variable *v, const void *newval)
 {
-  if (newval && (*(int*)newval == 1 || *(int*)newval == 0)) {
-    g.debug = *(int*)newval;
+  if (newval && (*(const int*)newval == 1 || *(const int*)newval == 0)) {
+    g.debug = *(const int*)newval;
   }
   return owl_variable_bool_set_default(v, newval);
 }
 
 /* When 'aaway' is changed, need to notify the AIM server */
-int owl_variable_aaway_set(owl_variable *v, void *newval)
+int owl_variable_aaway_set(owl_variable *v, const void *newval)
 {
   if (newval) {
-    if (*(int*)newval == 1) {
+    if (*(const int*)newval == 1) {
       owl_aim_set_awaymsg(owl_global_get_aaway_msg(&g));
-    } else if (*(int*)newval == 0) {
+    } else if (*(const int*)newval == 0) {
       owl_aim_set_awaymsg("");
     }
   }
   return owl_variable_bool_set_default(v, newval);
 }
 
-int owl_variable_pseudologins_set(owl_variable *v, void *newval)
+int owl_variable_pseudologins_set(owl_variable *v, const void *newval)
 {
   if (newval) {
-    if (*(int*)newval == 1) {
+    if (*(const int*)newval == 1) {
       owl_function_zephyr_buddy_check(0);
     }
   }
@@ -433,24 +443,21 @@ int owl_variable_pseudologins_set(owl_variable *v, void *newval)
 
 /* note that changing the value of this will clobber 
  * any user setting of this */
-int owl_variable_disable_ctrl_d_set(owl_variable *v, void *newval)
+int owl_variable_disable_ctrl_d_set(owl_variable *v, const void *newval)
 {
-
-  if (in_regtest) return owl_variable_int_set_default(v, newval);
-
   if (newval && !owl_context_is_startup(owl_global_get_context(&g))) {
-    if (*(int*)newval == 2) {
+    if (*(const int*)newval == 2) {
       owl_function_command_norv("bindkey editmulti C-d command edit:delete-next-char");
-    } else if (*(int*)newval == 1) {
-      owl_function_command_norv("bindkey editmulti C-d command editmulti:done-or-delete");
+    } else if (*(const int*)newval == 1) {
+      owl_function_command_norv("bindkey editmulti C-d command edit:done-or-delete");
     } else {
-      owl_function_command_norv("bindkey editmulti C-d command editmulti:done");
+      owl_function_command_norv("bindkey editmulti C-d command edit:done");
     }
   }  
   return owl_variable_int_set_default(v, newval);  
 }
 
-int owl_variable_tty_set(owl_variable *v, void *newval)
+int owl_variable_tty_set(owl_variable *v, const void *newval)
 {
   owl_zephyr_set_locationinfo(owl_global_get_hostname(&g), newval);
   return(owl_variable_string_set_default(v, newval));
@@ -466,7 +473,7 @@ int owl_variable_dict_setup(owl_vardict *vd) {
   if (owl_dict_create(vd)) return(-1);
   for (var = variables_to_init; var->name != NULL; var++) {
     cur = owl_malloc(sizeof(owl_variable));
-    memcpy(cur, var, sizeof(owl_variable));
+    *cur = *var;
     switch (cur->type) {
     case OWL_VARIABLE_OTHER:
       cur->set_fn(cur, cur->pval_default);
@@ -482,8 +489,8 @@ int owl_variable_dict_setup(owl_vardict *vd) {
 	cur->get_fn = owl_variable_get_default;
       if (!cur->get_tostring_fn) 
 	cur->get_tostring_fn = owl_variable_string_get_tostring_default;      
-      if (!cur->free_fn) 
-	cur->free_fn = owl_variable_free_default;
+      if (!cur->delete_fn)
+	cur->delete_fn = owl_variable_delete_default;
       cur->set_fn(cur, cur->pval_default);
       break;
     case OWL_VARIABLE_BOOL:
@@ -497,8 +504,8 @@ int owl_variable_dict_setup(owl_vardict *vd) {
 	cur->get_fn = owl_variable_get_default;
       if (!cur->get_tostring_fn) 
 	cur->get_tostring_fn = owl_variable_bool_get_tostring_default;      
-      if (!cur->free_fn) 
-	cur->free_fn = owl_variable_free_default;
+      if (!cur->delete_fn)
+	cur->delete_fn = owl_variable_delete_default;
       cur->val = owl_malloc(sizeof(int));
       cur->set_fn(cur, &cur->ival_default);
       break;
@@ -513,8 +520,8 @@ int owl_variable_dict_setup(owl_vardict *vd) {
 	cur->get_fn = owl_variable_get_default;
       if (!cur->get_tostring_fn) 
 	cur->get_tostring_fn = owl_variable_int_get_tostring_default;      
-      if (!cur->free_fn) 
-	cur->free_fn = owl_variable_free_default;
+      if (!cur->delete_fn)
+	cur->delete_fn = owl_variable_delete_default;
       cur->val = owl_malloc(sizeof(int));
       cur->set_fn(cur, &cur->ival_default);
       break;
@@ -522,18 +529,18 @@ int owl_variable_dict_setup(owl_vardict *vd) {
       fprintf(stderr, "owl_variable_setup: invalid variable type\n");
       return(-2);
     }
-    owl_dict_insert_element(vd, cur->name, (void*)cur, NULL);
+    owl_dict_insert_element(vd, cur->name, cur, NULL);
   }
   return 0;
 }
 
 void owl_variable_dict_add_variable(owl_vardict * vardict,
                                     owl_variable * var) {
-  owl_dict_insert_element(vardict, var->name, (void*)var, (void(*)(void*))owl_variable_free);
+  owl_dict_insert_element(vardict, var->name, var, (void (*)(void *))owl_variable_delete);
 }
 
-owl_variable * owl_variable_newvar(char *name, char *summary, char * description) {
-  owl_variable * var = (owl_variable*)owl_malloc(sizeof(owl_variable));
+owl_variable * owl_variable_newvar(const char *name, const char *summary, const char * description) {
+  owl_variable * var = owl_malloc(sizeof(owl_variable));
   memset(var, 0, sizeof(owl_variable));
   var->name = owl_strdup(name);
   var->summary = owl_strdup(summary);
@@ -541,14 +548,14 @@ owl_variable * owl_variable_newvar(char *name, char *summary, char * description
   return var;
 }
 
-void owl_variable_update(owl_variable *var, char *summary, char *desc) {
+void owl_variable_update(owl_variable *var, const char *summary, const char *desc) {
   if(var->summary) owl_free(var->summary);
   var->summary = owl_strdup(summary);
   if(var->description) owl_free(var->description);
   var->description = owl_strdup(desc);
 }
 
-void owl_variable_dict_newvar_string(owl_vardict * vd, char *name, char *summ, char * desc, char * initval) {
+void owl_variable_dict_newvar_string(owl_vardict * vd, const char *name, const char *summ, const char * desc, const char * initval) {
   owl_variable *old = owl_variable_get_var(vd, name, OWL_VARIABLE_STRING);
   if(old) {
     owl_variable_update(old, summ, desc);
@@ -562,13 +569,13 @@ void owl_variable_dict_newvar_string(owl_vardict * vd, char *name, char *summ, c
     var->set_fromstring_fn = owl_variable_string_set_fromstring_default;
     var->get_fn = owl_variable_get_default;
     var->get_tostring_fn = owl_variable_string_get_tostring_default;
-    var->free_fn = owl_variable_free_default;
+    var->delete_fn = owl_variable_delete_default;
     var->set_fn(var, initval);
     owl_variable_dict_add_variable(vd, var);
   }
 }
 
-void owl_variable_dict_newvar_int(owl_vardict * vd, char *name, char *summ, char * desc, int initval) {
+void owl_variable_dict_newvar_int(owl_vardict * vd, const char *name, const char *summ, const char * desc, int initval) {
   owl_variable *old = owl_variable_get_var(vd, name, OWL_VARIABLE_INT);
   if(old) {
     owl_variable_update(old, summ, desc);
@@ -582,14 +589,14 @@ void owl_variable_dict_newvar_int(owl_vardict * vd, char *name, char *summ, char
     var->set_fromstring_fn = owl_variable_int_set_fromstring_default;
     var->get_fn = owl_variable_get_default;
     var->get_tostring_fn = owl_variable_int_get_tostring_default;
-    var->free_fn = owl_variable_free_default;
+    var->delete_fn = owl_variable_delete_default;
     var->val = owl_malloc(sizeof(int));
     var->set_fn(var, &initval);
     owl_variable_dict_add_variable(vd, var);
   }
 }
 
-void owl_variable_dict_newvar_bool(owl_vardict * vd, char *name, char *summ, char * desc, int initval) {
+void owl_variable_dict_newvar_bool(owl_vardict * vd, const char *name, const char *summ, const char * desc, int initval) {
   owl_variable *old = owl_variable_get_var(vd, name, OWL_VARIABLE_BOOL);
   if(old) {
     owl_variable_update(old, summ, desc);
@@ -603,41 +610,44 @@ void owl_variable_dict_newvar_bool(owl_vardict * vd, char *name, char *summ, cha
     var->set_fromstring_fn = owl_variable_bool_set_fromstring_default;
     var->get_fn = owl_variable_get_default;
     var->get_tostring_fn = owl_variable_bool_get_tostring_default;
-    var->free_fn = owl_variable_free_default;
+    var->delete_fn = owl_variable_delete_default;
     var->val = owl_malloc(sizeof(int));
     var->set_fn(var, &initval);
     owl_variable_dict_add_variable(vd, var);
   }
 }
 
-void owl_variable_dict_free(owl_vardict *d) {
-  owl_dict_free_all(d, (void(*)(void*))owl_variable_free);
+void owl_variable_dict_cleanup(owl_vardict *d)
+{
+  owl_dict_cleanup(d, (void (*)(void *))owl_variable_delete);
 }
 
-/* free the list with owl_variable_dict_namelist_free */
-void owl_variable_dict_get_names(owl_vardict *d, owl_list *l) {
+/* free the list with owl_variable_dict_namelist_cleanup */
+void owl_variable_dict_get_names(const owl_vardict *d, owl_list *l) {
   owl_dict_get_keys(d, l);
 }
 
-void owl_variable_dict_namelist_free(owl_list *l) {
-  owl_list_free_all(l, owl_free);
+void owl_variable_dict_namelist_cleanup(owl_list *l)
+{
+  owl_list_cleanup(l, owl_free);
 }
 
-void owl_variable_free(owl_variable *v) {
-  if (v->free_fn) v->free_fn(v);
+void owl_variable_delete(owl_variable *v)
+{
+  if (v->delete_fn) v->delete_fn(v);
   owl_free(v);
 }
 
 
-char *owl_variable_get_description(owl_variable *v) {
+const char *owl_variable_get_description(const owl_variable *v) {
   return v->description;
 }
 
-char *owl_variable_get_summary(owl_variable *v) {
+const char *owl_variable_get_summary(const owl_variable *v) {
   return v->summary;
 }
 
-char *owl_variable_get_validsettings(owl_variable *v) {
+const char *owl_variable_get_validsettings(const owl_variable *v) {
   if (v->validsettings) {
     return v->validsettings;
   } else {
@@ -648,7 +658,7 @@ char *owl_variable_get_validsettings(owl_variable *v) {
 /* functions for getting and setting variable values */
 
 /* returns 0 on success, prints a status msg if msg is true */
-int owl_variable_set_fromstring(owl_vardict *d, char *name, char *value, int msg, int requirebool) {
+int owl_variable_set_fromstring(owl_vardict *d, const char *name, const char *value, int msg, int requirebool) {
   owl_variable *v;
   char buff2[1024];
   if (!name) return(-1);
@@ -677,16 +687,16 @@ int owl_variable_set_fromstring(owl_vardict *d, char *name, char *value, int msg
   return 0;
 }
  
-int owl_variable_set_string(owl_vardict *d, char *name, char *newval) {
+int owl_variable_set_string(owl_vardict *d, const char *name, const char *newval) {
   owl_variable *v;
   if (!name) return(-1);
   v = owl_dict_find_element(d, name);
   if (v == NULL || !v->set_fn) return(-1);
   if (v->type!=OWL_VARIABLE_STRING) return(-1);
-  return v->set_fn(v, (void*)newval);
+  return v->set_fn(v, newval);
 }
  
-int owl_variable_set_int(owl_vardict *d, char *name, int newval) {
+int owl_variable_set_int(owl_vardict *d, const char *name, int newval) {
   owl_variable *v;
   if (!name) return(-1);
   v = owl_dict_find_element(d, name);
@@ -695,15 +705,15 @@ int owl_variable_set_int(owl_vardict *d, char *name, int newval) {
   return v->set_fn(v, &newval);
 }
  
-int owl_variable_set_bool_on(owl_vardict *d, char *name) {
+int owl_variable_set_bool_on(owl_vardict *d, const char *name) {
   return owl_variable_set_int(d,name,1);
 }
 
-int owl_variable_set_bool_off(owl_vardict *d, char *name) {
+int owl_variable_set_bool_off(owl_vardict *d, const char *name) {
   return owl_variable_set_int(d,name,0);
 }
 
-int owl_variable_get_tostring(owl_vardict *d, char *name, char *buf, int bufsize) {
+int owl_variable_get_tostring(const owl_vardict *d, const char *name, char *buf, int bufsize) {
   owl_variable *v;
   if (!name) return(-1);
   v = owl_dict_find_element(d, name);
@@ -711,7 +721,7 @@ int owl_variable_get_tostring(owl_vardict *d, char *name, char *buf, int bufsize
   return v->get_tostring_fn(v, buf, bufsize, v->val);
 }
 
-int owl_variable_get_default_tostring(owl_vardict *d, char *name, char *buf, int bufsize) {
+int owl_variable_get_default_tostring(const owl_vardict *d, const char *name, char *buf, int bufsize) {
   owl_variable *v;
   if (!name) return(-1);
   v = owl_dict_find_element(d, name);
@@ -723,7 +733,7 @@ int owl_variable_get_default_tostring(owl_vardict *d, char *name, char *buf, int
   }
 }
 
-owl_variable *owl_variable_get_var(owl_vardict *d, char *name, int require_type) {
+owl_variable *owl_variable_get_var(const owl_vardict *d, const char *name, int require_type) {
   owl_variable *v;
   if (!name) return(NULL);
   v = owl_dict_find_element(d, name);
@@ -732,37 +742,37 @@ owl_variable *owl_variable_get_var(owl_vardict *d, char *name, int require_type)
 }
 
 /* returns a reference */
-void *owl_variable_get(owl_vardict *d, char *name, int require_type) {
+const void *owl_variable_get(const owl_vardict *d, const char *name, int require_type) {
   owl_variable *v = owl_variable_get_var(d, name, require_type);
   if(v == NULL) return NULL;
   return v->get_fn(v);
 }
 
 /* returns a reference */
-char *owl_variable_get_string(owl_vardict *d, char *name) {
-  return (char*)owl_variable_get(d,name, OWL_VARIABLE_STRING);
+const char *owl_variable_get_string(const owl_vardict *d, const char *name) {
+  return owl_variable_get(d,name, OWL_VARIABLE_STRING);
 }
 
 /* returns a reference */
-void *owl_variable_get_other(owl_vardict *d, char *name) {
-  return (char*)owl_variable_get(d,name, OWL_VARIABLE_OTHER);
+const void *owl_variable_get_other(const owl_vardict *d, const char *name) {
+  return owl_variable_get(d,name, OWL_VARIABLE_OTHER);
 }
 
-int owl_variable_get_int(owl_vardict *d, char *name) {
-  int *pi;
-  pi = (int*)owl_variable_get(d,name,OWL_VARIABLE_INT);
+int owl_variable_get_int(const owl_vardict *d, const char *name) {
+  const int *pi;
+  pi = owl_variable_get(d,name,OWL_VARIABLE_INT);
   if (!pi) return(-1);
   return(*pi);
 }
 
-int owl_variable_get_bool(owl_vardict *d, char *name) {
-  int *pi;
-  pi = (int*)owl_variable_get(d,name,OWL_VARIABLE_BOOL);
+int owl_variable_get_bool(const owl_vardict *d, const char *name) {
+  const int *pi;
+  pi = owl_variable_get(d,name,OWL_VARIABLE_BOOL);
   if (!pi) return(-1);
   return(*pi);
 }
 
-void owl_variable_describe(owl_vardict *d, char *name, owl_fmtext *fm) {
+void owl_variable_describe(const owl_vardict *d, const char *name, owl_fmtext *fm) {
   char defaultbuf[50];
   char buf[1024];
   int buflen = 1023;
@@ -786,7 +796,7 @@ void owl_variable_describe(owl_vardict *d, char *name, owl_fmtext *fm) {
   owl_fmtext_append_normal(fm, buf);
 }
 
-void owl_variable_get_help(owl_vardict *d, char *name, owl_fmtext *fm) {
+void owl_variable_get_help(const owl_vardict *d, const char *name, owl_fmtext *fm) {
   char buff[1024];
   int bufflen = 1023;
   owl_variable *v;
@@ -840,31 +850,32 @@ void owl_variable_get_help(owl_vardict *d, char *name, owl_fmtext *fm) {
 
 /* default common functions */
 
-void *owl_variable_get_default(owl_variable *v) {
+const void *owl_variable_get_default(const owl_variable *v) {
   return v->val;
 }
 
-void owl_variable_free_default(owl_variable *v) {
+void owl_variable_delete_default(owl_variable *v)
+{
   if (v->val) owl_free(v->val);
 }
 
 /* default functions for booleans */
 
-int owl_variable_bool_validate_default(owl_variable *v, void *newval) {
+int owl_variable_bool_validate_default(const owl_variable *v, const void *newval) {
   if (newval == NULL) return(0);
-  else if (*(int*)newval==1 || *(int*)newval==0) return(1);
+  else if (*(const int*)newval==1 || *(const int*)newval==0) return(1);
   else return (0);
 }
 
-int owl_variable_bool_set_default(owl_variable *v, void *newval) {
+int owl_variable_bool_set_default(owl_variable *v, const void *newval) {
   if (v->validate_fn) {
     if (!v->validate_fn(v, newval)) return(-1);
   }
-  *(int*)v->val = *(int*)newval;
+  *(int*)v->val = *(const int*)newval;
   return(0);
 }
 
-int owl_variable_bool_set_fromstring_default(owl_variable *v, char *newval) {
+int owl_variable_bool_set_fromstring_default(owl_variable *v, const char *newval) {
   int i;
   if (!strcmp(newval, "on")) i=1;
   else if (!strcmp(newval, "off")) i=0;
@@ -872,14 +883,14 @@ int owl_variable_bool_set_fromstring_default(owl_variable *v, char *newval) {
   return (v->set_fn(v, &i));
 }
 
-int owl_variable_bool_get_tostring_default(owl_variable *v, char* buf, int bufsize, void *val) {
+int owl_variable_bool_get_tostring_default(const owl_variable *v, char* buf, int bufsize, const void *val) {
   if (val == NULL) {
     snprintf(buf, bufsize, "<null>");
     return -1;
-  } else if (*(int*)val == 0) {
+  } else if (*(const int*)val == 0) {
     snprintf(buf, bufsize, "off");
     return 0;
-  } else if (*(int*)val == 1) {
+  } else if (*(const int*)val == 1) {
     snprintf(buf, bufsize, "on");
     return 0;
   } else {
@@ -890,54 +901,54 @@ int owl_variable_bool_get_tostring_default(owl_variable *v, char* buf, int bufsi
 
 /* default functions for integers */
 
-int owl_variable_int_validate_default(owl_variable *v, void *newval) {
+int owl_variable_int_validate_default(const owl_variable *v, const void *newval) {
   if (newval == NULL) return(0);
   else return (1);
 }
 
-int owl_variable_int_set_default(owl_variable *v, void *newval) {
+int owl_variable_int_set_default(owl_variable *v, const void *newval) {
   if (v->validate_fn) {
     if (!v->validate_fn(v, newval)) return(-1);
   }
-  *(int*)v->val = *(int*)newval;
+  *(int*)v->val = *(const int*)newval;
   return(0);
 }
 
-int owl_variable_int_set_fromstring_default(owl_variable *v, char *newval) {
+int owl_variable_int_set_fromstring_default(owl_variable *v, const char *newval) {
   int i;
-  char *ep = "x";
+  char *ep;
   i = strtol(newval, &ep, 10);
   if (*ep || ep==newval) return(-1);
   return (v->set_fn(v, &i));
 }
 
-int owl_variable_int_get_tostring_default(owl_variable *v, char* buf, int bufsize, void *val) {
+int owl_variable_int_get_tostring_default(const owl_variable *v, char* buf, int bufsize, const void *val) {
   if (val == NULL) {
     snprintf(buf, bufsize, "<null>");
     return -1;
   } else {
-    snprintf(buf, bufsize, "%d", *(int*)val);
+    snprintf(buf, bufsize, "%d", *(const int*)val);
     return 0;
   } 
 }
 
 /* default functions for enums (a variant of integers) */
 
-int owl_variable_enum_validate(owl_variable *v, void *newval) {  
+int owl_variable_enum_validate(const owl_variable *v, const void *newval) {  
   char **enums;
   int nenums, val;
   if (newval == NULL) return(0);
   enums = atokenize(v->validsettings, ",", &nenums);
   if (enums == NULL) return(0);
-  atokenize_free(enums, nenums);
-  val = *(int*)newval;
+  atokenize_delete(enums, nenums);
+  val = *(const int*)newval;
   if (val < 0 || val >= nenums) {
     return(0);
   }
   return(1);
 }
 
-int owl_variable_enum_set_fromstring(owl_variable *v, char *newval) {
+int owl_variable_enum_set_fromstring(owl_variable *v, const char *newval) {
   char **enums;
   int nenums, i, val=-1;
   if (newval == NULL) return(-1);
@@ -948,12 +959,12 @@ int owl_variable_enum_set_fromstring(owl_variable *v, char *newval) {
       val = i;
     }
   }
-  atokenize_free(enums, nenums);
+  atokenize_delete(enums, nenums);
   if (val == -1) return(-1);
   return (v->set_fn(v, &val));
 }
 
-int owl_variable_enum_get_tostring(owl_variable *v, char* buf, int bufsize, void *val) {
+int owl_variable_enum_get_tostring(const owl_variable *v, char* buf, int bufsize, const void *val) {
   char **enums;
   int nenums, i;
 
@@ -962,24 +973,25 @@ int owl_variable_enum_get_tostring(owl_variable *v, char* buf, int bufsize, void
     return -1;
   }
   enums = atokenize(v->validsettings, ",", &nenums);
-  i = *(int*)val;
+  i = *(const int*)val;
   if (i<0 || i>=nenums) {
     snprintf(buf, bufsize, "<invalid:%d>",i);
-    atokenize_free(enums, nenums);
+    atokenize_delete(enums, nenums);
     return(-1);
   }
   snprintf(buf, bufsize, "%s", enums[i]);
+  atokenize_delete(enums, nenums);
   return 0;
 }
 
 /* default functions for stringeans */
 
-int owl_variable_string_validate_default(struct _owl_variable *v, void *newval) {
+int owl_variable_string_validate_default(const struct _owl_variable *v, const void *newval) {
   if (newval == NULL) return(0);
   else return (1);
 }
 
-int owl_variable_string_set_default(owl_variable *v, void *newval) {
+int owl_variable_string_set_default(owl_variable *v, const void *newval) {
   if (v->validate_fn) {
     if (!v->validate_fn(v, newval)) return(-1);
   }
@@ -988,95 +1000,17 @@ int owl_variable_string_set_default(owl_variable *v, void *newval) {
   return(0);
 }
 
-int owl_variable_string_set_fromstring_default(owl_variable *v, char *newval) {
+int owl_variable_string_set_fromstring_default(owl_variable *v, const char *newval) {
   return (v->set_fn(v, newval));
 }
 
-int owl_variable_string_get_tostring_default(owl_variable *v, char* buf, int bufsize, void *val) {
+int owl_variable_string_get_tostring_default(const owl_variable *v, char* buf, int bufsize, const void *val) {
   if (val == NULL) {
     snprintf(buf, bufsize, "<null>");
     return -1;
   } else {
-    snprintf(buf, bufsize, "%s", (char*)val);
+    snprintf(buf, bufsize, "%s", (const char*)val);
     return 0;
   }
 }
 
-
-
-/**************************************************************************/
-/************************* REGRESSION TESTS *******************************/
-/**************************************************************************/
-
-#ifdef OWL_INCLUDE_REG_TESTS
-
-#include "test.h"
-
-int owl_variable_regtest(void) {
-  owl_vardict vd;
-  int numfailed=0;
-  char buf[1024];
-  owl_variable * v;
-
-  in_regtest = 1;
-
-  printf("# BEGIN testing owl_variable\n");
-  FAIL_UNLESS("setup", 0==owl_variable_dict_setup(&vd));
-
-  FAIL_UNLESS("get bool", 0==owl_variable_get_bool(&vd,"rxping"));
-  FAIL_UNLESS("get bool (no such)", -1==owl_variable_get_bool(&vd,"mumble"));
-  FAIL_UNLESS("get bool as string 1", 0==owl_variable_get_tostring(&vd,"rxping", buf, 1024));
-  FAIL_UNLESS("get bool as string 2", 0==strcmp(buf,"off"));
-  FAIL_UNLESS("set bool 1", 0==owl_variable_set_bool_on(&vd,"rxping"));
-  FAIL_UNLESS("get bool 2", 1==owl_variable_get_bool(&vd,"rxping"));
-  FAIL_UNLESS("set bool 3", 0==owl_variable_set_fromstring(&vd,"rxping","off",0,0));
-  FAIL_UNLESS("get bool 4", 0==owl_variable_get_bool(&vd,"rxping"));
-  FAIL_UNLESS("set bool 5", -1==owl_variable_set_fromstring(&vd,"rxping","xxx",0,0));
-  FAIL_UNLESS("get bool 6", 0==owl_variable_get_bool(&vd,"rxping"));
-
-
-  FAIL_UNLESS("get string", 0==strcmp("~/zlog/people", owl_variable_get_string(&vd,"logpath")));
-  FAIL_UNLESS("set string 7", 0==owl_variable_set_string(&vd,"logpath","whee"));
-  FAIL_UNLESS("get string", 0==strcmp("whee", owl_variable_get_string(&vd,"logpath")));
-
-  FAIL_UNLESS("get int", 8==owl_variable_get_int(&vd,"typewinsize"));
-  FAIL_UNLESS("get int (no such)", -1==owl_variable_get_int(&vd,"mmble"));
-  FAIL_UNLESS("get int as string 1", 0==owl_variable_get_tostring(&vd,"typewinsize", buf, 1024));
-  FAIL_UNLESS("get int as string 2", 0==strcmp(buf,"8"));
-  FAIL_UNLESS("set int 1", 0==owl_variable_set_int(&vd,"typewinsize",12));
-  FAIL_UNLESS("get int 2", 12==owl_variable_get_int(&vd,"typewinsize"));
-  FAIL_UNLESS("set int 1b", -1==owl_variable_set_int(&vd,"typewinsize",-3));
-  FAIL_UNLESS("get int 2b", 12==owl_variable_get_int(&vd,"typewinsize"));
-  FAIL_UNLESS("set int 3", 0==owl_variable_set_fromstring(&vd,"typewinsize","9",0,0));
-  FAIL_UNLESS("get int 4", 9==owl_variable_get_int(&vd,"typewinsize"));
-  FAIL_UNLESS("set int 5", -1==owl_variable_set_fromstring(&vd,"typewinsize","xxx",0,0));
-  FAIL_UNLESS("set int 6", -1==owl_variable_set_fromstring(&vd,"typewinsize","",0,0));
-  FAIL_UNLESS("get int 7", 9==owl_variable_get_int(&vd,"typewinsize"));
-
-  owl_variable_dict_newvar_string(&vd, "stringvar", "", "", "testval");
-  FAIL_UNLESS("get new string var", NULL != (v = owl_variable_get(&vd, "stringvar", OWL_VARIABLE_STRING)));
-  FAIL_UNLESS("get new string val", !strcmp("testval", owl_variable_get_string(&vd, "stringvar")));
-  owl_variable_set_string(&vd, "stringvar", "new val");
-  FAIL_UNLESS("update string val", !strcmp("new val", owl_variable_get_string(&vd, "stringvar")));
-
-  owl_variable_dict_newvar_int(&vd, "intvar", "", "", 47);
-  FAIL_UNLESS("get new int var", NULL != (v = owl_variable_get(&vd, "intvar", OWL_VARIABLE_INT)));
-  FAIL_UNLESS("get new int val", 47 == owl_variable_get_int(&vd, "intvar"));
-  owl_variable_set_int(&vd, "intvar", 17);
-  FAIL_UNLESS("update bool val", 17 == owl_variable_get_int(&vd, "intvar"));
-
-  owl_variable_dict_newvar_bool(&vd, "boolvar", "", "", 1);
-  FAIL_UNLESS("get new bool var", NULL != (v = owl_variable_get(&vd, "boolvar", OWL_VARIABLE_BOOL)));
-  FAIL_UNLESS("get new bool val", owl_variable_get_bool(&vd, "boolvar"));
-  owl_variable_set_bool_off(&vd, "boolvar");
-  FAIL_UNLESS("update string val", !owl_variable_get_bool(&vd, "boolvar"));
-
-  owl_variable_dict_free(&vd);
-
-  /* if (numfailed) printf("*** WARNING: failures encountered with owl_variable\n"); */
-  printf("# END testing owl_variable (%d failures)\n", numfailed);
-  return(numfailed);
-}
-
-
-#endif /* OWL_INCLUDE_REG_TESTS */
